@@ -107,7 +107,7 @@ class BaseHandler(RequestHandler):
                 logging.error("异常码：" + str(error.code))
                 logging.error("异常信息：" + error.message)
 
-            logging.error("参数:" + (json.dumps(self.params) if hasattr(self, "params") else str(self.request.arguments or {})))
+            logging.error("参数:" + (json.dumps(self.params, ensure_ascii=False) if hasattr(self, "params") else str(self.request.arguments or {})))
             if not hasattr(error, "code_name") or not hasattr(error, "code"):
                 return self.write_failed()
             else:
@@ -274,6 +274,10 @@ class BaseSchema(object):
     is_shard = False
     shard_key = ""
 
+    @classmethod
+    def ts(cls):
+        return int(time.time())
+
     @classmethod
     def fields(cls):
         return vars(cls())
@@ -335,6 +339,47 @@ class BaseSchema(object):
     def dbo(cls, sql=None, shard_key_value=None):
         return cls.mongo[cls.get_shard_table(sql=sql, shard_key_value=shard_key_value)]
 
+    @classmethod
+    def get_by_oid(cls, oid, shard_key_value=None, **kwargs):
+        """
+        单条记录
+        :return:
+        :rtype:
+        """
+        return cls.find_one_by_oid(oid, shard_key_value=None, **kwargs)
+
+    @classmethod
+    def get_by_spec(cls, spec, shard_key_value=None, **kwargs):
+        """
+        条件查询
+        :param spec:
+        :return:
+        """
+        return cls.find_one(spec)
+
+    @classmethod
+    def create(cls, **kwargs):
+        """
+        创建
+        :return:
+        :rtype:
+        """
+        docs = cls.fields()
+        for k, v in kwargs.items():
+            if k in docs:
+                docs[k] = v
+        return cls.insert(docs)
+
+    @classmethod
+    def delete(cls, oid, shard_key_value=None, **kwargs):
+        """
+        删除
+        注意，使用该方法时，默认-1
+        :return:
+        :rtype:
+        """
+        return cls.update({"_id": oid}, {"$set": {"state": -1}})
+
     @classmethod
     def count(cls, sql=None, shard_key_value=None, **kwargs):
         """
@@ -456,7 +501,7 @@ class BaseSchema(object):
         spec = cls.__check_id(spec)
         kwargs.setdefault("max_time_ms", 60*1000)
         d = cls.dbo(sql=spec, shard_key_value=shard_key_value).find_one(spec or {}, **kwargs) or {}
-        return cls.__parse_oid(d)
+        return cls._parse_data(cls.__parse_oid(d)) if d else {}
 
     @classmethod
     def find(cls, spec=None, fields=False, limit=False, skip=False, sort=False, is_cursor=False, shard_key_value=None):
@@ -488,11 +533,8 @@ class BaseSchema(object):
 
         if is_cursor:
             return cursor
-
-        for d in cursor:
-            data.append(cls.__parse_oid(d))
-
-        return data
+        else:
+            return list(cursor)
 
     @classmethod
     def distinct(cls, spec, distinct, shard_key_value=None, **kwargs):
@@ -624,7 +666,7 @@ class BaseSchema(object):
                                                                                sort=kwargs.pop("sort", None),
                                                                                full_response=kwargs.pop("full_response", False),
                                                                                manipulate=kwargs.pop("manipulate", False), **kwargs)
-        return cls.__parse_oid(d)
+        return cls._parse_data(cls.__parse_oid(d)) if d else {}
 
     @classmethod
     def find_one_and_replace(cls, spec, docs, shard_key_value=None, **kwargs):
@@ -650,7 +692,7 @@ class BaseSchema(object):
             kwargs["sort"] = list(sort.items())
         kwargs.setdefault("return_document", True)
         d = cls.dbo(sql=spec, shard_key_value=shard_key_value).find_one_and_replace(spec, docs, **kwargs)
-        return cls.__parse_oid(d)
+        return cls._parse_data(cls.__parse_oid(d)) if d else {}
 
     @classmethod
     def find_one_and_update(cls, spec, docs, shard_key_value=None, **kwargs):
@@ -681,7 +723,7 @@ class BaseSchema(object):
             kwargs["sort"] = list(sort.items())
         docs.setdefault("$set", {})['update_at'] = utils.now()
         d = cls.dbo(sql=spec, shard_key_value=shard_key_value).find_one_and_update(spec, docs, **kwargs)
-        return cls.__parse_oid(d)
+        return cls._parse_data(cls.__parse_oid(d)) if d else {}
 
     @classmethod
     def find_one_and_delete(cls, spec, shard_key_value=None, **kwargs):
@@ -709,7 +751,7 @@ class BaseSchema(object):
         if sort and type(sort) == dict:
             kwargs["sort"] = list(sort.items())
         d = cls.dbo(sql=spec, shard_key_value=shard_key_value).find_one_and_delete(spec, **kwargs)
-        return cls.__parse_oid(d)
+        return cls._parse_data(cls.__parse_oid(d)) if d else {}
 
     @classmethod
     def find_list_by_page(cls, spec, page, count=10, sort={"create_at": -1}, fields=False, shard_key_value=None):
@@ -721,7 +763,7 @@ class BaseSchema(object):
         :return:
         """
         cursor = cls.find(spec, fields=fields, is_cursor=True, shard_key_value=shard_key_value)
-        data_list = [cls.__parse_oid(c) for c in list(cls.__meta_cursor(cursor, page, count, sort))]
+        data_list = [cls._parse_data(cls.__parse_oid(d)) for d in list(cls.__meta_cursor(cursor, page, count, sort)) if d]
         total_page = cls.__get_total_page(cursor, count)
         return data_list, total_page
 
@@ -735,7 +777,7 @@ class BaseSchema(object):
         :return:
         """
         cursor = cls.find(spec, fields=fields, is_cursor=True, shard_key_value=shard_key_value)
-        data_list = [cls.__parse_oid(c) for c in list(cls.__meta_cursor(cursor, count=count, sort=sort))]
+        data_list = [cls._parse_data(cls.__parse_oid(d)) for d in list(cls.__meta_cursor(cursor, count=count, sort=sort)) if d]
         last_id_field = last_id_field if last_id_field else "create_at"
         last_id = data_list[-1][last_id_field] - 1 if data_list else -1
         return data_list, last_id
@@ -752,18 +794,27 @@ class BaseSchema(object):
         data_mp = {}
         skip_field_list = kwargs.get("skip_field_list", [])
 
-        data, __ = cls.find_list_by_page({key: {"$in": vals}}, 0, 0, **kwargs)
-        for d in data:
-            d = cls.__parse_oid(d)
-            tmp = {}
-            for k, v in d.items():
-                if k in skip_field_list:
-                    continue
-                tmp[k] = v
+        shard_key_value = kwargs.get("shard_key_value", None)
+        fields = kwargs.get("fields", None)
+        page = kwargs.get("page", 0)
+        count = kwargs.get("count", 0)
+        sort = kwargs.get("sort", {"create_at": -1})
 
+        cursor = cls.find({key: {"$in": vals}}, fields=fields, is_cursor=True, shard_key_value=shard_key_value)
+        data = [cls.__parse_oid(d) for d in list(cls.__meta_cursor(cursor, 0, 0, sort)) if d]
+
+        for d in data:
+            tmp = {}
+            if skip_field_list:
+                for k, v in d.items():
+                    if k in skip_field_list:
+                        continue
+                    tmp[k] = v
+            else:
+                tmp = d
             data_mp[d[key]] = tmp
 
-        return data_mp
+        return {k: cls._parse_data(v) for k, v in data_mp.items()}
 
     @classmethod
     def next_seq_id(cls, seq_name="seq_id", val=0, random_step=10):
@@ -780,6 +831,19 @@ class BaseSchema(object):
             return result['val']
         return None
 
+    @classmethod
+    def _parse_data(cls, d, **kwargs):
+        """
+        you can rewrite this，in model
+        :return:
+        :rtype:
+        """
+        name = cls.__name__.lower().rstrip("model")
+        id_name = "%s_id" % name
+        if "_id" in d and id_name not in d:
+            d[id_name] = str(d["_id"]) if utils.ObjectId.is_valid(d["_id"]) else d["_id"]
+        return d
+
     @classmethod
     def __meta_cursor(cls, cursor, page=None, count=10, sort=dict()):
         sort = list(sort.items()) if type(sort) == dict else list(sort) if sort else False
@@ -839,6 +903,8 @@ class BaseSchema(object):
                     spec[k] = utils.to_ObjectId(v)
         return spec
 
+
+
     @classmethod
     def __parse_date(cls, d):
         if not d:
