@@ -139,7 +139,7 @@ def get_params(self, fill_default=True):
                         # 参数为数组
                         params_vaule = self.get_arguments(params_name) or None
                     else:
-                        params_vaule = self.get_argument(params_name, None, strip=False)
+                        params_vaule = self.get_argument(params_name, None, strip=True)
                 else:
                     if not body_arguments:
                         raise errors.ErrorArgumentValue
@@ -163,14 +163,14 @@ def get_params(self, fill_default=True):
                         # 参数为数组
                         params_vaule = self.get_arguments(params_name) or None
                     else:
-                        params_vaule = self.get_argument(params_name, None, strip=False)
+                        params_vaule = self.get_argument(params_name, None, strip=True)
 
                 elif _in in ["www-form", "body-form"]:
                     if item["type"] == "list":
                         # 参数为数组
                         params_vaule = self.get_arguments(params_name) or None
                     else:
-                        params_vaule = self.get_argument(params_name, None, strip=False)
+                        params_vaule = self.get_argument(params_name, None, strip=True)
 
                 elif _in in ["body-json"]:
                     if self.request.arguments:
@@ -178,7 +178,7 @@ def get_params(self, fill_default=True):
                             # 参数为数组
                             params_vaule = self.get_arguments(params_name) or None
                         else:
-                            params_vaule = self.get_argument(params_name, None, strip=False)
+                            params_vaule = self.get_argument(params_name, None, strip=True)
                     else:
                         if self.request.body:
                             body_arguments = {k: v for k, v in [item.split("=") for item in self.request.body.decode().split("&")]}
@@ -206,7 +206,7 @@ def get_params(self, fill_default=True):
                         else:
                             params_vaule = files[params_name][0]
                     else:
-                        params_vaule = self.get_argument(params_name, None, strip=False)
+                        params_vaule = self.get_argument(params_name, None, strip=True)
 
                 elif _in in ["binary"]:
                     msg = "参数：'%s'，不再支持将参数位置设置为binary方式" % params_name
