@@ -2,7 +2,7 @@
 # -*- coding:utf-8 -*-
 import webbrowser, os
 from ..base import BaseHandler
-
+import platform
 
 class DocsHandler(BaseHandler):
     """
@@ -25,10 +25,12 @@ class DocsHandler(BaseHandler):
             self.redirect(host)
         else:
             html_path = "index.html" if self.app_config.get("output","html") else "docs/build/html/index.html"
-            file_path = "file://"+os.path.realpath("/%s/%s/%s"%(self.app_config["ROOT"],
-                                                                self.app_config["api_docs"]["docs_dir"],
-                                                                html_path
-                                                                ))
+            file_path = os.path.realpath("/%s/%s/%s" % (self.app_config["ROOT"],
+                                                        self.app_config["api_docs"]["docs_dir"],
+                                                        html_path
+                                                        ))
+            if platform.system() != "Windows":
+                file_path = "file://" + file_path
             webbrowser.open(file_path)
 
 
